@@ -1,11 +1,11 @@
 package App::Netdisco::Daemon::Worker::Poller::Common;
 
 use Dancer qw/:moose :syntax :script/;
+use Dancer::Plugin::DBIC 'schema';
 
 use App::Netdisco::Util::SNMP 'snmp_connect';
 use App::Netdisco::Util::Device 'get_device';
 use App::Netdisco::Daemon::Util ':all';
-use Dancer::Plugin::DBIC 'schema';
 
 use NetAddr::IP::Lite ':lower';
 
@@ -16,22 +16,38 @@ use namespace::clean;
 sub _walk_body {
   my ($self, $job_type, $job) = @_;
 
-  my $layer_method = $job_type .'_layer';
-  my $job_layer = $self->$layer_method;
+  my $devices = schema('netdisco')->resultset('Device')->get_column('ip');
+  my $jobqueue = schema('netdisco')->resultset('Admin');
 
-  my %queued = map {$_ => 1} $self->jq_queued($job_type);
-  my @devices = schema('netdisco')->resultset('Device')
-    ->has_layer($job_layer)->get_column('ip')->all;
-  my @filtered_devices = grep {!exists $queued{$_}} @devices;
+  if ($job->subaction and $job->subaction eq 'after-discoverall') {
+      # make sure there are no incomplete discover jobs queued
+      my $discover = $jobqueue->search(
+        { action => 'discover', status => { -like => 'queued%' } }
+      )->count;
 
-  $self->jq_insert([
+      return job_defer("Deferred $job_type due to pending discover jobs")
+        if $discover;
+  }
+
+  schema('netdisco')->txn_do(sub {
+    # clean up user submitted jobs older than 1min,
+    # assuming skew between schedulers' clocks is not greater than 1min
+    $jobqueue->search({
+        action => $job_type,
+        status => 'queued',
+        entered => { '<' => \"(now() - interval '1 minute')" },
+    })->delete;
+
+    # is scuppered by any user job submitted in last 1min (bad), or
+    # any similar job from another scheduler (good)
+    $jobqueue->populate([
       map {{
           device => $_,
           action => $job_type,
-          username => $job->username,
-          userip => $job->userip,
-      }} (@filtered_devices)
-  ]);
+          status => 'queued',
+      }} ($devices->all)
+    ]);
+  });
 
   return job_done("Queued $job_type job for all devices");
 }
@@ -50,14 +66,7 @@ sub _single_body {
 
   if ($device->in_storage
       and $device->vendor and $device->vendor eq 'netdisco') {
-      return job_done("$job_type skipped: $host is pseudo-device");
-  }
-
-  my $filter_method = $job_type .'_filter';
-  my $job_filter = $self->$filter_method;
-
-  unless ($job_filter->($device->ip)) {
-      return job_defer("$job_type deferred: $host is not ${job_type}able");
+      return job_done("Skipped $job_type for pseudo-device $host");
   }
 
   my $snmp = snmp_connect($device);
@@ -74,23 +83,4 @@ sub _single_body {
   return job_done("Ended $job_type for ". $host->addr);
 }
 
-sub _single_node_body {
-  my ($self, $job_type, $node, $now) = @_;
-
-  my $action_method = $job_type .'_action';
-  my $job_action = $self->$action_method;
-
-  my $filter_method = $job_type .'_filter';
-  my $job_filter = $self->$filter_method;
-
-  unless ($job_filter->($node)) {
-      return job_defer("$job_type deferred: $node is not ${job_type}able");
-  }
-
-  $job_action->($node, $now);
-
-  # would be ignored if wrapped in a loop
-  return job_done("Ended $job_type for $node");
-}
-
 1;
