@@ -3,13 +3,14 @@ package App::Netdisco::Web::Plugin::Search::Port;
 use Dancer ':syntax';
 use Dancer::Plugin::Ajax;
 use Dancer::Plugin::DBIC;
+use Dancer::Plugin::Auth::Extensible;
 
 use App::Netdisco::Web::Plugin;
 
 register_search_tab({ tag => 'port', label => 'Port' });
 
 # device ports with a description (er, name) matching
-ajax '/ajax/content/search/port' => sub {
+ajax '/ajax/content/search/port' => require_login sub {
     my $q = param('q');
     send_error('Missing query', 400) unless $q;
     my $set;
